function result = Backbone(C)
% result = Backbone(C) returns coordinates, resnum, & resname, & angles for
% the backbone of a protein chain C

select = strarraycmp(char(' C', ' N', ' CA'), C.aname);
result.coords = C.coords(select,:); 
result.resnum = C.resnum(select);
result.resname = C.resname(select,:);
result.aname = C.aname(select,:);
result.anum = C.anum(select,:);
result.altid = C.altid(select,:);


v = diff(result.coords); % row differences give vectors
len = sqrt(dot(v,v,2));
v = v ./ repmat(len,1,3); % normalize rows

nv = size(v,1); nv1 = nv-1; nv2=nv-2;

uv = dot(v(1:nv1,:), v(2:nv,:), 2); % cos of angles between adjacent
bondangles = 180/pi*acos(uv); % bond angles

uprime = v(1:nv2,:) - repmat(uv(1:nv2),1,3).* v(2:nv1,:); % project prev: u onto vperp
uprime = uprime ./ repmat(sqrt(dot(uprime, uprime, 2)), 1,3); % normalize
wprime = v(3:nv,:) - repmat(uv(2:nv1),1,3).* v(2:nv1,:); % project succ: w onto vperp
wprime = wprime ./ repmat(sqrt(dot(wprime, wprime, 2)), 1,3); % normalize
uw = cross(uprime, wprime, 2); 

sn = -sign(dot(uw,v(2:nv1,:),2)) .* sqrt(dot(uw,uw,2)); % sine is magnitude of cross product
cs = -dot(uprime, wprime, 2); % cosine is dot product
%disp( sn.^2+cs.^2); % check
phipsiomega = 180/pi*atan2(sn, cs); % compute angles
%uv2 = uv.^2;
%uw = dot(v(1:nv2,:), v(3:nv,:), 2); % cos of angles of next to adjacent
%phipsi = 180/pi*acos((uw - uv(1:nv2).*uv(2:nv1)) ./ sqrt((1-uv2(1:nv2)).*(1-uv2(2:nv1))));

result.lengths = reshape([NaN; len], 3, ceil(nv/3))';
result.bondang = reshape([NaN; bondangles; NaN], 3, ceil(nv/3))';
result.dihedrals = reshape([NaN; phipsiomega; NaN; NaN], 3, ceil(nv/3))';
result.dihedrals(:,3) = 180 + result.dihedrals(:,3) - 360*(result.dihedrals(:,3)>0);

subplot(2,2,1); plot(result.lengths); title('Backbone bond lengths');
subplot(2,2,2); plot(result.bondang); title('Backbone bond outer angles');
subplot(2,2,3); plot(result.dihedrals); title('Backbone dihedral angles');
subplot(2,2,4); plot(result.dihedrals(:,1), result.dihedrals(:,2), 'o'); 
axis([-180 180 -180 180]); title('Ramachandran plot');
