function result = SideCentroids(C)
% result = SideCentroids(C) returns a list of coordinates of
% sidechain centroids along the backbone of a protein 

[result.resnum, ci, ri] = unique(C.resnum); % one for each residue
result.resname = C.resname(ci,:); 
n = length(result.resnum);
count = zeros(n,1);
coords = zeros(n,3); 
for i = find(~strarraycmp(char(' C  ',' N  ', ' O  '), C.aname))' % average sidechain coordinates
    count(ri(i)) = count(ri(i))+1;
    coords(ri(i),:) = coords(ri(i),:) + C.coords(i,:);
end
result.coords = coords ./ repmat(count,1,3);

v = diff(result.coords); % row differences gives vectors
len = sqrt(dot(v,v,2));
nv = size(v,1);
angles = 180/pi*acos(dot(v(1:(nv-1),:), v(2:nv,:), 2) ./ len(1:(nv-1)) ./ len(2:nv)); % dot products give cos(angles)
result.lengths = len;
result.angles = angles;
