function result = pdbRead(file, hetatm)
% C = pdbRead(file) reads pdb file into structure C,
% which contains five parallel arrays:
% Atom name, number, Residue name, number, & coordinates.
% C.aname, anum, resname, resnum, coords
% Pass 1 as second argument to read HETATM records

if nargin < 2, hetatm = 0; end % don't read HETATM by default
fid = fopen(file); %open for reading
i = 0; 

fid = fopen(file); %open for reading
i = 0; looping = 1;

maxn = 10000;
C = zeros(maxn,3); 
anum = zeros(maxn, 1);
resnum = anum;
aname = repmat('    ', maxn, 1);
resname = aname(:,1:3);
chainid = aname(:, 1);
altid = chainid;

tline = fgetl(fid);
while ischar(tline)
    if ((length(tline) >= 54) & (strcmpi(tline(1:6), 'ATOM  ') | (hetatm & strcmpi(tline(1:6), 'HETATM'))))
        i = i+1; % got a good line in tline
        C(i,1) = str2num(tline(31:38)); %coordinates
        C(i,2) = str2num(tline(39:46)); 
        C(i,3) = str2num(tline(47:54)); 
        anum(i) = str2num(tline(7:11)); %atom number
        aname(i,:) = upper(tline(13:16)); %atom name
        resnum(i) = str2num(tline(23:26)); %residue number
        resname(i,:) = upper(tline(18:20)); %residue name
        chainid(i) = upper(tline(22));
        altid(i) = upper(tline(17));
    end
    tline = fgetl(fid);
end

result.aname = aname(1:i,:);
result.anum = anum(1:i);
result.resname = resname(1:i,:);
result.resnum = resnum(1:i);
result.chainid = chainid(1:i);
result.altid = altid(1:i);
result.coords = C(1:i,:);


fprintf('%d atoms read. Chains:', i); % alert for different chains
disp(unique(chainid')); 

fprintf('Alt:'); disp(unique(altid')); % alert for alt configurations

fprintf('Non-amino residues:');
res = unique(resname,'rows');
aa = ['ALA';'ARG';'ASN';'ASP';'CYS';'GLN';'GLU';'GLY';'HIS';'ILE';'LEU';'LYS';'MET';'PHE';'PRO';'SER';'THR';'TRP';'TYR';'VAL'];
disp(res(~strarraycmp(aa, res), :));

gaps = find(diff(resnum) > 1)'; % find gaps in residue numbering
fprintf('Gaps:\n'); 
for i = gaps
    if (~(strcmp('HOH',resname(i,:))& strcmp('HOH',resname(i+1,:)))) % skip water/water gaps
        fprintf(' %i: %d %s -- %d %s\n', i, resnum(i), resname(i,:), resnum(i+1,:), resname(i+1,:));
    end
end
